Slot: in_subset - LinkML Model

# Slot: in_subset

used to indicate membership of a term in a defined subset of terms used for a particular domain or application (e.g. the translator_minimal subset holding the minimal set of predicates used in a translator knowledge graph)

URI: linkml:in_subset

## Domain and Range

Element → 0..* SubsetDefinition

## Parents

## Children

## Used by

- ClassDefinition
- CommonMetadata
- Definition
- Element
- EnumDefinition
- PermissibleValue
- SchemaDefinition
- SlotDefinition
- SubsetDefinition
- TypeDefinition

## Other properties

Mappings: |  | OIO:inSubset